@@ -8,15 +8,15 @@ from os import path
 from xlang import logger
 
 
-def file_name(abspath: str) -> str:
+def get_file_name(abspath: str) -> str:
     return path.splitext(path.basename(abspath))[0]
 
 
-def file_suffix(abspath: str) -> str:
+def get_file_suffix(abspath: str) -> str:
     return path.splitext(path.basename(abspath))[1]
 
 
-def path_split(abspath: str):
+def split_path(abspath: str):
     dir_path, f_name, suffix = '', '', ''
     if abspath:
         dir_path = path.dirname(abspath)
